@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 module Data.Binary.Instances.Aeson where
 
@@ -11,6 +12,11 @@ import Data.Binary.Instances.Vector ()
 
 import qualified Data.Aeson as A
 
+#if MIN_VERSION_aeson(2,0,0)
+import qualified Data.Aeson.Key as Key
+import qualified Data.Aeson.KeyMap as KM
+#endif
+
 instance Binary A.Value where
     get = do
         t <- get :: Get Int
@@ -29,3 +35,13 @@ instance Binary A.Value where
     put (A.Number v) = put (3 :: Int) >> put v
     put (A.Bool v)   = put (4 :: Int) >> put v
     put A.Null       = put (5 :: Int)
+
+#if MIN_VERSION_aeson(2,0,0)
+instance Binary Key.Key where
+    get = Key.fromText <$> get
+    put = put . Key.toText
+
+instance Binary v => Binary (KM.KeyMap v) where
+    get = fmap KM.fromList get
+    put = put . KM.toList
+#endif
